@@ -228,6 +228,7 @@ g_unix_is_mount_path_system_internal (const char *mount_path)
     "/srv",
     "/tmp",
     "/usr",
+    "/usr/local",
     "/var",
     "/var/log/audit", /* https://bugzilla.redhat.com/show_bug.cgi?id=333041 */
     "/var/tmp",       /* https://bugzilla.redhat.com/show_bug.cgi?id=335241 */
@@ -1808,6 +1809,14 @@ g_unix_mount_point_guess_icon (GUnixMountPoint *mount_point)
   return g_themed_icon_new (type_to_icon (g_unix_mount_point_guess_type (mount_point), TRUE));
 }
 
+/**
+ * g_unix_mount_guess_can_eject:
+ * @mount_entry: a #GUnixMountEntry
+ * 
+ * Guesses whether a Unix mount can be ejected.
+ *
+ * Returns: %TRUE if @mount_entry is deemed to be ejectable.
+ */
 gboolean
 g_unix_mount_guess_can_eject (GUnixMountEntry *mount_entry)
 {
@@ -1821,6 +1830,14 @@ g_unix_mount_guess_can_eject (GUnixMountEntry *mount_entry)
   return FALSE;
 }
 
+/**
+ * g_unix_mount_point_guess_can_eject:
+ * @mount_point: a #GUnixMountPoint
+ * 
+ * Guesses whether a Unix mount point can be ejected.
+ *
+ * Returns: %TRUE if @mount_point is deemed to be ejectable.
+ */
 gboolean
 g_unix_mount_point_guess_can_eject (GUnixMountPoint *mount_point)
 {
